#ifndef __OLED_GUI_H
#define __OLED_GUI_H		

#include "OLED_Driver.h"
#include "../Fonts/fonts.h"

/********************************************************************************
function:	
			dot pixel
********************************************************************************/
typedef enum{
	DOT_PIXEL_1X1  = 1,		// dot pixel 1 x 1
	DOT_PIXEL_2X2  , 		// dot pixel 2 X 2 
	DOT_PIXEL_3X3  ,		// dot pixel 3 X 3
	DOT_PIXEL_4X4  ,		// dot pixel 4 X 4
	DOT_PIXEL_5X5  , 		// dot pixel 5 X 5
	DOT_PIXEL_6X6  , 		// dot pixel 6 X 6
	DOT_PIXEL_7X7  , 		// dot pixel 7 X 7
	DOT_PIXEL_8X8  , 		// dot pixel 8 X 8
}DOT_PIXEL;
#define DOT_PIXEL_DFT  DOT_PIXEL_1X1  //Default dot pilex

/********************************************************************************
function:	
			dot Fill style
********************************************************************************/
typedef enum{
	DOT_FILL_AROUND  = 1,		// dot pixel 1 x 1
	DOT_FILL_RIGHTUP  , 		// dot pixel 2 X 2 
}DOT_STYLE;
#define DOT_STYLE_DFT  DOT_FILL_AROUND  //Default dot pilex
/********************************************************************************
function:	
			solid line and dotted line
********************************************************************************/
typedef enum{
	LINE_SOLID = 0,
	LINE_DOTTED,
}LINE_STYLE;

/********************************************************************************
function:	
			DRAW Internal fill
********************************************************************************/
typedef enum{
	DRAW_EMPTY = 0,
	DRAW_FULL,
}DRAW_FILL;

/********************************************************************************
function:	
	time
********************************************************************************/
typedef struct{
	uint16_t Year;  //0000
	uint8_t  Month; //1 - 12
	uint8_t  Day;   //1 - 30
	uint8_t  Hour;  //0 - 23
	uint8_t  Min;   //0 - 59 	
	uint8_t  Sec;   //0 - 59
}DEV_TIME;
extern DEV_TIME sDev_time;

/********************************************************************************
function:	
			Defines commonly used colors for the display
********************************************************************************/
#define OLED_BACKGROUND		BLACK   //Default background color
#define FONT_BACKGROUND		BLACK   //Default font background color
#define FONT_FOREGROUND	    WHITE    //Default font foreground color

//Color is 16-bit depth
#define WHITE          0xF
#define BLACK          0x0

/********************************************************************************
function:	
			Macro definition variable name
********************************************************************************/
//Drawing
void GUI_DrawPoint(POINT Xpoint, POINT Ypoint, COLOR Color, DOT_PIXEL Dot_Pixel, DOT_STYLE Dot_FillWay);
void GUI_DrawLine(POINT Xstart, POINT Ystart, POINT Xend, POINT Yend, COLOR Color, LINE_STYLE Line_Style, DOT_PIXEL Dot_Pixel);
void GUI_DrawRectangle(POINT Xstart, POINT Ystart, POINT Xend, POINT Yend, COLOR Color, DRAW_FILL Filled , DOT_PIXEL Dot_Pixel );
void GUI_DrawCircle(POINT X_Center, POINT Y_Center, LENGTH Radius, COLOR Color, DRAW_FILL Draw_Fill , DOT_PIXEL Dot_Pixel );

//pic
void GUI_Disbitmap(POINT Xpoint, POINT Ypoint, const unsigned char *pMap, POINT Width, POINT Height);
void GUI_DisGrayMap(POINT Xpoint, POINT Ypoint, const unsigned char *pBmp);

//Display string
void GUI_DisChar(POINT Xstart, POINT Ystart, const char Acsii_Char, sFONT* Font, COLOR Color_Background, COLOR Color_Foreground);
void GUI_DisString_EN(POINT Xstart, POINT Ystart, const char * pString, sFONT* Font, COLOR Color_Background, COLOR Color_Foreground );
void GUI_DisNum(POINT Xpoint, POINT Ypoint, int32_t Nummber, sFONT* Font, COLOR Color_Background, COLOR Color_Foreground );
void GUI_Showtime(POINT Xstart, POINT Ystart, POINT Xend, POINT Yend, DEV_TIME *pTime, COLOR Color);
//show
void GUI_Show(void);

static const unsigned char gImage_P[8198] = {  0X00,0X04,0X80,0X00,0X80,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X8C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,
0X88,0X8C,0XCF,0XFF,0XFF,0XFC,0XFF,0X00,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X00,
0X00,0X00,0X08,0XCF,0X88,0X88,0X88,0X08,0X88,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X00,0X00,
0X00,0X00,0X00,0X0C,0X80,0X8C,0XC8,0X88,0XC8,0X8F,0XFC,0XCC,0X8C,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X80,0X00,0X00,
0X00,0X00,0X00,0X00,0X80,0X8F,0XFF,0XCC,0XFC,0X08,0XC8,0X80,0X08,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X80,0X00,0X00,0X00,
0X00,0X00,0X00,0X08,0XFC,0XFF,0XFF,0XFF,0XFF,0X88,0XCC,0X80,0X00,0X8F,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X8C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XCF,0XFF,0XF8,0X08,0XCF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0X0C,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X08,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0XCF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X00,0XCF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X00,0X00,0X08,0X80,0X88,
0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X08,0XCF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X00,0X00,0X08,0X80,0X8F,
0XFC,0X80,0X00,0XCC,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0XF8,0X8F,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X08,0X80,0X08,
0XCF,0XFC,0X00,0X08,0X8C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0XC8,0X8F,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X00,0X08,0X88,0X00,
0X08,0XCF,0XF8,0X08,0X08,0XCC,0X88,0X88,0X88,0X88,0X8C,0XCC,0X80,0X00,0X8F,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X00,0X0C,0X8C,0X88,
0X80,0X08,0XF8,0X00,0X00,0X88,0X00,0X00,0X88,0X88,0X00,0X00,0X00,0X08,0X88,0X8F,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X00,0X08,0X88,0X88,
0X8C,0X00,0XF8,0X08,0X00,0X08,0X88,0X88,0XFF,0XFF,0XCC,0X88,0X00,0X08,0XFC,0X88,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X00,0XC8,0X00,0XC8,0X88,
0X8C,0X80,0XC8,0XCC,0X80,0X88,0X88,0X80,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X0F,0XFC,
0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X0C,0XFF,0X00,0X88,0XCC,
0X88,0X00,0X88,0XFF,0XC0,0XC8,0X8C,0X80,0X8C,0XFF,0XFF,0XFF,0XFF,0XFC,0X00,0XCF,
0XF8,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X8F,0XFF,0XF8,0X00,0X88,
0X88,0X08,0XCF,0XFF,0XC0,0X88,0X8C,0X88,0X08,0X88,0X88,0X88,0X8C,0XFF,0X80,0X88,
0XFF,0X88,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X88,0XFF,0XFF,0XFF,0X80,0X00,
0X08,0X8C,0XFF,0XFF,0XC0,0X8C,0X88,0XCC,0X88,0X88,0X88,0X80,0X08,0XFF,0X80,0X08,
0XFF,0XF8,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X8C,0XFF,0XFF,0XFF,0XFF,0XCC,
0XCF,0XFF,0XFF,0XFF,0XF0,0X8C,0X8C,0XC8,0X8C,0X88,0X8C,0XCC,0X08,0XFC,0X80,0XCF,
0XFF,0XFF,0X80,0X8F,0XFF,0XFF,0XCC,0X88,0XCC,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0XCF,0XFC,0XCF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XF0,0X0C,0X88,0X88,0XCC,0X8C,0XC8,0X88,0X08,0XCC,0XCF,0XFF,
0XFF,0XFF,0XF8,0X08,0XFF,0XC8,0X00,0X00,0X08,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X88,0XC8,0X80,0X00,0X88,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFC,0X00,0XC8,0XCC,0X88,0X88,0X8C,0X80,0X08,0XCC,0XFF,0XFF,
0XFF,0XFF,0XFF,0X80,0X88,0X00,0X00,0X00,0X00,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X08,0X00,0X00,0X00,0X00,0XCF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFC,0X80,0X88,0XC8,0XC8,0XCC,0X8C,0X80,0X08,0XCF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XC0,0X00,0X00,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X00,0X00,0X00,0X00,0X00,0X8F,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X00,0X88,0X88,0X88,0X88,0X80,0X8C,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XF0,0X00,0X00,0X00,0X00,0X00,0X00,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X00,0X00,0X08,0XCC,0XCC,0X80,0X8F,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X00,0X00,0X00,0X00,0X88,0XCF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X00,0X08,0XCF,0XFF,0XFF,0XC0,0X8F,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X00,0X00,0X88,0X88,0XCF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X00,0X00,0X8C,0XFF,0XFF,0XFF,0XF8,0X8F,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X00,0X00,0X00,0X8C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0XC8,0X00,0X08,0XCF,0XFF,0XFF,0XFC,0XFC,0XCF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XC8,0X00,0X00,0X00,0X00,0X00,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XF0,0X00,0X00,0X00,0X00,0X00,0X00,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFC,0XCC,0XC8,0X00,0X0C,0XFF,0XFF,0XFC,0X00,0XCF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFC,0X88,0X8C,0XC8,0X00,0X00,0X00,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XF8,0X00,0X00,0X00,0X00,0X00,0X00,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XC8,0XCF,0XF8,0X00,0X8F,0XFF,0XFF,0XC0,0X00,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XC8,0XCF,0XFF,0XFF,0XF8,0X00,0X00,0X00,0XCF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFC,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFC,0X8C,0XFF,0XF8,0X00,0X8F,0XFF,0XFC,0X00,0X00,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0X00,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0X88,0XCF,0XFF,0XF0,0X00,0XCF,0XFF,0XF8,0X00,0X08,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0X00,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XF8,0X8C,0XFF,0XFF,0XF0,0X00,0XCF,0XFF,0XF0,0X00,0X8C,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFC,0X80,0X8F,0XFF,0XFF,0XFF,0XF0,0X00,0X00,0X0C,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0X80,0XCF,0XFF,0XFF,0XF8,0X00,0X8F,0XFF,0XC0,0X00,0XCF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XC0,0X00,0X0F,0XFF,0XFF,0XFF,0XF0,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFC,0X08,0XFF,0XFF,0XFF,0XFC,0X00,0X0F,0XFF,0XC0,0X08,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XF0,0X00,0X00,0X00,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XC8,0X8F,0XFF,0XFF,0XFF,0XFF,0X88,0X08,0XFF,0XF8,0XCF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XF8,0X00,0X00,0XCF,0XFF,0XFF,0XFF,0XF0,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0X08,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0X80,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XC0,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XF0,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFC,0X00,0X00,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFC,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0XC8,0XCF,0XFF,0XFF,0XFF,
0XFF,0X80,0X00,0X0C,0XFF,0XFF,0XFF,0XFF,0XC0,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFC,0X00,0X00,0X00,0X00,0X00,0X8C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XF8,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X88,0X0C,0XFF,0XFF,0XFF,
0XFF,0X80,0X00,0XCF,0XFF,0XFF,0XFF,0XFF,0X80,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFC,0X00,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XF0,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0X88,0X08,0XCF,0XFF,0XFF,
0XFF,0XC0,0X88,0XFF,0XFF,0XFF,0XFF,0XFC,0X00,0X00,0X00,0X0C,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X08,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XC0,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0XCC,0XFC,0XFF,0XFF,0XFF,
0XFF,0XFC,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0X08,0X88,0X88,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0X80,0XFF,0XFF,0XFC,0X8C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XF8,0XCF,0XFF,0XFF,0XFF,0XFC,0X00,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFC,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0X00,0XFF,0XFF,0XFC,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XF0,0X0C,0XFF,0XFF,0XFC,0X88,0X00,0X00,0X00,0X08,0XCF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XF8,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0X00,0XFF,0XFF,0XFF,0X88,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XF8,0X00,0X08,0X88,0X80,0X00,0X00,0X00,0X00,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XF8,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0X00,0XFF,0XFF,0XFF,0XC0,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XF8,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0X00,0XFF,0XFF,0XFF,0XF0,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XC8,0X00,0X00,0X00,0X00,0X00,0X00,0X8C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XF8,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0X80,0XCF,0XFF,0XFF,0XFF,0X08,0XFF,0XFF,0XFF,0XFF,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFC,0X80,0X00,0X00,0X00,0X00,0X88,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XC8,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XC0,0X8F,0XFF,0XFF,0XFF,0XC8,0X0C,0XFF,0XFF,0XCC,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XC8,0X88,0X88,0X8C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0X88,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XF0,0X0F,0XFF,0XFF,0XFF,0XFC,0XC8,0X08,0X88,0X8C,0X80,0XCF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0X88,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XF8,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0XCC,0XCF,0XF0,0X8F,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X88,0XCF,0XFF,0XFF,0XFF,
0XFC,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X0C,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFC,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X80,0X00,0X8C,0XFF,0XFF,0XFF,
0XFF,0X00,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0XCF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XF8,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X00,0X00,0X08,0XFF,0XFF,0XFF,
0XFF,0XC0,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF0,0X8F,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XF8,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X00,0X00,0X08,0XFF,0XFF,0XFF,
0XFF,0XF0,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X08,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XC0,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,
0XFF,0XFC,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0X8F,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XC0,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X88,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,
0XFF,0XFF,0X80,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X00,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XCC,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0X88,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X00,0X00,0X00,0X00,0X00,0X8C,0XFF,0XFF,
0XFF,0XFF,0XC0,0X8F,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X0C,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X00,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X80,0X00,0X00,0X00,0X88,0XC8,0X00,0X08,0XCF,
0XFF,0XFF,0XFC,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0X8C,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X88,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFC,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X00,0X00,0X00,0X00,0XCC,0X8C,0XC8,0X80,0X00,
0X8C,0XFF,0XFF,0X80,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X80,
0X88,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XCC,0X8C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XF8,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X00,0X00,0X00,0X08,0XC8,0X88,0X8C,0XCC,0X88,
0X08,0X8C,0XFF,0XF0,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,
0X88,0X88,0XCC,0XCC,0XCC,0XCC,0X88,0X88,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XF0,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X08,0X88,0X88,0X8C,0X88,0X8C,
0X88,0X00,0X08,0XFF,0X08,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFC,0XC8,0X88,0X88,0X88,0XCC,0XCC,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XC0,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X8C,0XC8,
0XCC,0XC8,0X00,0X88,0XC0,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0X88,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0X88,0X88,0X00,0X08,0XCC,
0X8C,0X88,0XCC,0X80,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFC,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X8C,0XCF,0XFF,0XC8,0X00,0X0C,
0X88,0XC8,0XCC,0X8C,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XF8,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X00,0X00,0X08,0XCC,0X8C,0XCF,0XFF,0X80,0X0C,
0XC8,0XC8,0X88,0X88,0XC8,0X80,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0X88,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X00,0X00,0X88,0X88,0X00,0X8C,0XFF,0XC8,0X08,
0XCC,0X8C,0X88,0X80,0X08,0XC8,0X00,0X08,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,
0X88,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X08,0XC8,0X88,0X88,0X08,0XCC,0XFC,0X00,
0X8C,0X8C,0X88,0XC8,0X00,0X8C,0X88,0X80,0X08,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X80,
0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X8C,0X88,0XCF,0XFF,0X80,0XCC,0XFC,0X00,
0X8C,0X8C,0X00,0X8F,0XF0,0X08,0XCC,0XC8,0X80,0X08,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X08,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X08,0XCC,0X8C,0XFF,0XFF,0XC0,0XCC,0XCF,0X00,
0X8C,0XC8,0X80,0X08,0XC8,0X88,0XC8,0X8C,0XC8,0X80,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X08,0X8F,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X08,0XC8,0XCF,0XFF,0XFF,0XC0,0XCC,0XCC,0X00,
0X8C,0X88,0XCC,0X80,0X00,0X8C,0X8C,0XCC,0XCC,0X88,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X88,0X00,0X8F,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X08,0X88,0XFF,0XFF,0XFF,0XC0,0XCC,0XFC,0X00,
0X88,0X8C,0XCC,0XC8,0X88,0X8C,0XCC,0X8C,0X88,0X08,0X88,0X00,0XC8,0X8C,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0XC8,0X88,0X88,0XCF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X88,0X0C,0X88,0XFF,0XFF,0XFF,0X88,0XCF,0XC8,0X00,
0X8C,0XCC,0X88,0X88,0X8C,0X88,0XCC,0X88,0XC8,0X88,0X8C,0X80,0X00,0X00,0X8C,0XFF,
0XCC,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XCC,0XC8,0X80,0X00,0X88,0XCF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X88,0X0F,0X0C,0XFF,0XFF,0XFF,0X88,0XCF,0XC8,0X00,
0X88,0X8C,0XCC,0X8C,0XCC,0X88,0XC8,0XCC,0X80,0X8C,0X8C,0X80,0X00,0X00,0X00,0X8F,
0X88,0X88,0X88,0XC8,0XCC,0X88,0X00,0X00,0X00,0X88,0XCC,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X80,0X8C,0X0C,0XFF,0XFF,0XFC,0X8C,0XCC,0XF8,0X00,
0XCC,0XC8,0XCC,0X8C,0X8C,0XCC,0X88,0XCC,0X80,0X8C,0X8C,0XC0,0X00,0X00,0X00,0X0C,
0XC8,0X88,0X80,0X00,0X88,0X00,0X08,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X80,0X8F,0X0C,0XFC,0XFF,0XC8,0X8C,0XCC,0XC0,0X08,
0X88,0XC8,0XCC,0XCC,0XCC,0X8C,0XCC,0XC8,0X08,0XC8,0X00,0X00,0X00,0X00,0X00,0X00,
0X80,0X88,0X88,0X00,0X88,0X88,0X88,0X80,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0X88,0XC0,0X8F,0X08,0XFF,0XFC,0X88,0XCF,0XCC,0X80,0X08,
0X88,0XCC,0XCC,0X8C,0XCC,0X88,0XCC,0X88,0X0C,0X80,0X00,0X00,0X00,0X00,0X00,0X00,
0X08,0X88,0X88,0X00,0X88,0X88,0X88,0X88,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0X88,0XC0,0X8F,0X80,0X8F,0XC8,0X8C,0XFF,0XFC,0X00,0X88,
0XC8,0XC8,0XCC,0X8C,0X8C,0XC8,0XC8,0X88,0X8C,0X80,0X00,0X00,0X00,0X00,0X00,0X00,
0X08,0X88,0X80,0X00,0X88,0X88,0X88,0X88,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XF8,0X88,0XC0,0X0F,0XC0,0X88,0X88,0XCC,0XFF,0XC8,0X00,0X88,
0X8C,0XCC,0XCC,0XC8,0X8C,0XC8,0XC8,0X08,0XC8,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X88,0X88,0X88,0X8C,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XC8,0X8C,0XC8,0X0C,0XF8,0X88,0XCC,0XFC,0XFF,0X80,0X08,0X88,
0X8C,0XCC,0X88,0XCC,0X88,0XCC,0XC8,0X08,0XCC,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X88,0X88,0X88,0X88,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0X88,0XC8,0XC8,0X08,0XCF,0XFC,0XCF,0XFF,0XC8,0X00,0X8C,0XCC,
0XCC,0XFF,0XC8,0X88,0XC8,0XCC,0X88,0X88,0X88,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X08,0X88,0X88,0X88,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFC,0X88,0XCC,0XCC,0X80,0X88,0XFF,0XFC,0XCC,0X80,0X08,0X8C,0XCF,
0XFF,0XFF,0XFC,0XC8,0XC8,0X88,0X88,0X8C,0X88,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X08,0X88,0X88,0X88,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XF8,0X8C,0X8C,0X88,0XC8,0X00,0X08,0X88,0X88,0X00,0X88,0XCF,0XFF,
0XFF,0XCC,0XFF,0XC8,0X88,0X88,0X88,0XC8,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X08,0X88,0X88,0X88,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XF8,0X0C,0XC8,0XC8,0XCC,0X80,0X00,0X08,0X80,0X88,0XCC,0XCF,0XFF,
0XFF,0XCC,0XFF,0XFC,0X8C,0X88,0X88,0XC8,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X08,0X88,0X88,0X88,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XF8,0X08,0XCC,0XCC,0X8C,0XCC,0X88,0X88,0X88,0X8C,0XCC,0XFF,0XFF,
0XFF,0XCC,0XFF,0XFF,0XCC,0X88,0X88,0XC8,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X08,0X88,0X88,0X88,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFC,0X00,0XCC,0X88,0XCC,0X8C,0XC8,0XCC,0XCC,0XC8,0X8C,0XFF,0XFC,
0XFF,0XFF,0XFF,0XFF,0X88,0X88,0X8C,0XC8,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X08,0X88,0X88,0X88,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0X80,0X08,0X8C,0XCC,0XCC,0X88,0X88,0XCC,0XCC,0X8C,0XFF,0XC8,
0X88,0XCF,0XFF,0XFF,0X88,0X08,0XCC,0XCC,0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X88,0X88,0X88,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XF8,0X00,0X88,0X88,0X88,0XCC,0XCC,0X88,0X8C,0X8C,0XFC,0XCF,
0XC8,0X8F,0XFF,0XFF,0X88,0X88,0XCC,0X88,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X88,0X88,0X88,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X00,0X88,0X88,0XCC,0XCC,0XCC,0XCC,0X8C,0XFF,0XFF,
0XFF,0X88,0XFF,0XFF,0X80,0X8C,0XCC,0XCC,0XC8,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0XC8,0X88,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X80,0X08,0X00,0X88,0X8C,0XCC,0XCC,0X8C,0XFF,0XFF,
0XFF,0XF8,0XCF,0XFC,0X88,0X8C,0X8C,0XCC,0XC8,0X00,0X88,0X8C,0X80,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0XC8,0X88,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X00,0X88,0X00,0X08,0X88,0XCC,0X88,0XFF,0XFF,
0XFF,0XFC,0XCF,0XF8,0X08,0XCC,0XCC,0X8C,0X88,0X0C,0XFF,0XFF,0XC0,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X88,0X88,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X00,0X88,0X80,0X08,0X88,0XC8,0XCF,0XFF,
0XFF,0XFC,0XFF,0XC8,0X88,0XCC,0XCC,0X8C,0X80,0X8F,0XFF,0XFF,0XF8,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X88,0X88,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X80,0X88,0X88,0X00,0X08,0X8C,0XFF,
0XFF,0XFF,0XFC,0X80,0X8C,0X88,0XCC,0XCC,0X80,0XCF,0XFF,0XFF,0XFF,0X80,0X00,0X00,
0X00,0X00,0X00,0X00,0X08,0X88,0X88,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X80,0X08,0XC8,0X80,0X08,0X8C,
0XCF,0XFC,0XC8,0X88,0XCC,0X88,0XCC,0XC8,0X08,0XFF,0XFF,0XFF,0XFF,0XF0,0X00,0X00,
0X00,0X00,0X00,0X00,0X08,0X88,0X80,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X08,0X88,0X80,0X08,
0X88,0XC8,0X88,0X88,0XCC,0X8C,0XC8,0X88,0X0C,0XFF,0XFF,0XFF,0XFF,0XFC,0X00,0X00,
0X00,0X00,0X00,0X00,0X88,0X88,0X88,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X00,0X88,0X88,
0X00,0X88,0X88,0X8C,0X8C,0XCC,0X8C,0X80,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0X00,
0X00,0X00,0X00,0X00,0X88,0X88,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X00,0X88,
0X88,0X88,0X88,0X8C,0XCC,0XCC,0XCC,0X80,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X80,
0X00,0X00,0X00,0X00,0X88,0XC8,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0X80,
0X88,0XCC,0X88,0X8C,0XCC,0X8C,0XC8,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,
0X00,0X00,0X00,0X88,0X88,0XC8,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0XFF,
0X88,0X88,0X88,0X88,0X88,0XCC,0XC0,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XCC,0X88,0X00,0X88,0X88,0X88,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0XFF,
0XFC,0X88,0X00,0X00,0X08,0X88,0X80,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0X80,0X88,0X88,0X88,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0XFF,
0XFF,0XFF,0XC8,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0X80,0X88,0X88,0X8C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0XFF,
0XFF,0XFF,0XFF,0XC8,0X80,0X08,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0X80,0X88,0X88,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF0,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFC,0XCC,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0X8C,0XFC,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF0,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFC,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF0,0XCF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFC,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF0,0X8F,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XF8,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X0F,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XF8,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X0F,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XC8,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X0C,
0XFF,0XFF,0XCC,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0X88,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X08,
0XFF,0XFF,0XC0,0X8C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0X8C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0XFF,0XFF,0XFF,0X00,0X88,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0XFF,0XFF,0XFF,0XFC,0X80,0X00,0X8C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF0,
0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X8C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF0,
0XCF,0XFF,0XFF,0XFF,0XFF,0XF0,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XF8,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0X00,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0XF0,0X0F,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0X00,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XF0,0X0F,0XF0,0XFF,0X00,0XF0,0X0F,0XF0,0XFF,0X00,0XF0,0X0F,0XF0,0XFF,0X00,0XFF,
0XFF,0X00,0X00,0X0F,0XF0,0X0F,0XF0,0X00,0X0F,0XFF,0X00,0XF0,0X00,0X00,0XF0,0X0F,
0XF0,0X00,0X0F,0XF0,0X00,0X00,0XFF,0X00,0XFF,0X00,0X0F,0X00,0XFF,0XF0,0X0F,0XFF,
0XF0,0X00,0XFF,0XF0,0X00,0X0F,0XF0,0X00,0X00,0X00,0X00,0XFF,0XFF,0XFF,0XFF,0XFF,
0XF0,0X0F,0X00,0X0F,0X00,0XF0,0X0F,0X00,0X0F,0X00,0XF0,0X0F,0X00,0X0F,0X00,0XFF,
0XFF,0X00,0XFF,0X00,0XF0,0X0F,0XF0,0X0F,0X00,0XF0,0X0F,0X00,0XFF,0X00,0XF0,0X0F,
0X00,0XFF,0X00,0XF0,0X0F,0XF0,0X0F,0X00,0XF0,0XFF,0X00,0XF0,0X0F,0X00,0XFF,0XFF,
0X00,0XF0,0X0F,0X00,0XFF,0X00,0XF0,0X0F,0XF0,0X0F,0XF0,0X0F,0XFF,0XFF,0XFF,0XFF,
0XF0,0X0F,0X00,0X0F,0X00,0XF0,0X0F,0X00,0X0F,0X00,0XF0,0X0F,0X00,0X0F,0X00,0XFF,
0XFF,0X00,0XFF,0X00,0XF0,0X0F,0XF0,0X0F,0X00,0XF0,0X0F,0X00,0XFF,0X00,0XF0,0X0F,
0X00,0X00,0XFF,0XF0,0X0F,0XF0,0X0F,0X00,0XFF,0X00,0X00,0XF0,0X0F,0X00,0XFF,0XFF,
0X00,0XFF,0XFF,0X00,0XFF,0X00,0XF0,0X0F,0XF0,0X0F,0XF0,0X0F,0XFF,0XFF,0XFF,0XFF,
0XFF,0X00,0X0F,0X00,0X0F,0XFF,0X00,0X0F,0X00,0X0F,0XFF,0X00,0X0F,0X00,0X0F,0XFF,
0XFF,0X00,0XFF,0X00,0XF0,0X0F,0XF0,0X0F,0X00,0XF0,0X0F,0X00,0XFF,0X00,0XF0,0X0F,
0XFF,0X00,0X00,0XF0,0X0F,0XF0,0X0F,0X00,0XF0,0X0F,0X00,0XF0,0X0F,0X00,0XFF,0XFF,
0X00,0XFF,0XFF,0X00,0XFF,0X00,0XF0,0X0F,0XF0,0X0F,0XF0,0X0F,0XFF,0XFF,0XFF,0XFF,
0XFF,0X00,0X0F,0X00,0X0F,0XFF,0X00,0X0F,0X00,0X0F,0XFF,0X00,0X0F,0X00,0X0F,0XF0,
0X0F,0X00,0XFF,0X00,0XF0,0X0F,0XF0,0X0F,0XF0,0X00,0XFF,0X00,0XFF,0X00,0XF0,0X0F,
0X00,0XFF,0X00,0XF0,0X0F,0XF0,0X0F,0X00,0XF0,0X0F,0X00,0XFF,0X00,0X0F,0XF0,0X0F,
0X00,0XF0,0X0F,0X00,0XFF,0X00,0XF0,0X0F,0XF0,0X0F,0XF0,0X0F,0XFF,0XFF,0XFF,0XFF,
0XFF,0X00,0XFF,0XF0,0X0F,0XFF,0X00,0XFF,0XF0,0X0F,0XFF,0X00,0XFF,0XF0,0X0F,0XF0,
0X0F,0X00,0X00,0X0F,0XFF,0X00,0X00,0X0F,0XF0,0X00,0XFF,0XF0,0X00,0X00,0XF0,0X0F,
0XF0,0X00,0X0F,0XF0,0X00,0X00,0XFF,0X00,0XFF,0X00,0X00,0XFF,0X00,0X0F,0XF0,0X0F,
0XF0,0X00,0XFF,0XF0,0X00,0X0F,0XF0,0X0F,0XF0,0X0F,0XF0,0X0F,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF0,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XF0,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF0,0X00,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XF0,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X0F,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
};

static const unsigned char gImage_P1[] = {0X00,0X04,0X80,0X00,0X3C,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X08,0XCC,0XFF,0XFF,0XFF,0XFC,0X8C,0XFF,
0X80,0X8C,0XCF,0XFF,0X80,0XCF,0XFF,0XFF,0XFF,0XFF,0XFC,0X80,0X00,0X88,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X00,0X00,0X88,0X8F,0XFF,0XC8,0XCF,0XFF,
0XFF,0XFF,0XFF,0XFF,0X88,0XFF,0XFF,0XFF,0XFF,0XFC,0X80,0X00,0X00,0X00,0X0C,0XFF,
0XFF,0XFF,0XFF,0XFC,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XCC,0XC8,0X88,0X80,0X00,0XC8,0X80,0X8C,0X8C,0XFF,0XFF,
0XFF,0XFF,0XFF,0XF8,0X00,0X08,0XCF,0XFF,0XFF,0XC8,0X00,0X00,0X00,0X00,0X00,0X8C,
0X88,0X8F,0XF8,0X00,0X8C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XC8,0X88,0X88,0X8C,0XCC,0X88,0XFF,0XFC,0X88,0X8F,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFC,0X88,0X80,0X08,0XFF,0XFF,0X80,0X00,0X00,0X00,0X00,0X00,0X08,
0X00,0X0C,0X80,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFC,0X80,0X88,0XCC,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X08,0XFF,0XFC,0X80,0X00,0X00,0X00,0X00,0X00,0X0C,
0X80,0X08,0X80,0X00,0X00,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XC8,0X00,0X08,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFC,0X80,0X08,0XFF,0XF8,0X00,0X00,0X00,0X00,0X00,0X00,0X0F,
0X80,0X00,0X00,0X00,0X00,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XC8,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XC8,0X88,0X00,0X00,0X00,0X0C,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X0F,
0X00,0X00,0X00,0X00,0X00,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0X88,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XC8,0X00,0X88,0X8C,0XCF,0XFC,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X8F,
0X00,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFC,0X8C,0XFF,0XFC,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0X88,0X00,0X0C,0XFF,0XFF,0XFF,0XFF,0XF8,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X8F,
0X00,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XF8,0X8C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,
0X00,0X00,0X8F,0XFC,0X88,0X88,0XCF,0XFC,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X8C,
0X00,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XC0,0X0C,0XFF,0XFF,0XFF,0XCC,0X88,0XCC,0XCF,0XFF,0XFF,0XF8,0X00,
0X88,0X80,0X08,0X80,0X00,0X80,0X0F,0XFC,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X8F,
0X00,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFC,0X80,0X0C,0XFF,0XC8,0X88,0X80,0X00,0X00,0X08,0XFC,0X88,0X80,0X08,
0X88,0XC8,0X08,0X88,0X88,0X80,0X8F,0XF8,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X8C,
0X00,0X00,0X00,0X00,0X08,0XCC,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFC,0X80,0X0C,0XC8,0X00,0X88,0X8C,0XFF,0XCF,0X80,0X00,0X00,0X00,0X88,
0X88,0X88,0X88,0X88,0XC8,0X80,0XCF,0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X0F,
0X00,0X00,0X00,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XF0,0X00,0X00,0XCF,0XC8,0X88,0X8C,0XFF,0XC0,0X08,0X80,0X00,0X08,
0X88,0X8C,0X88,0X88,0X88,0X80,0X8C,0X8C,0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X0F,
0X00,0X00,0X00,0X00,0X00,0X00,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFC,0XC0,0X00,0X00,0X88,0X00,0X00,0X08,0XFF,0XF0,0X0C,0XFF,0XFC,0X00,
0X08,0X8C,0X88,0X88,0X88,0X80,0X08,0X8F,0XFC,0X80,0X00,0X00,0X00,0X00,0X00,0X08,
0X00,0X00,0X00,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XC8,0X00,0X8C,0X80,0X00,0X08,0X88,0X00,0XFF,0X80,0XCF,0XFF,0XFF,0XC8,
0X00,0X08,0X88,0X88,0X88,0X00,0X0C,0XFF,0XFF,0XF8,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X08,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0XCC,0XCC,0XCF,0XFF,0XFF,
0XFF,0XFC,0X80,0X08,0X88,0X88,0X88,0X88,0X88,0X08,0XFC,0X88,0XFF,0XFF,0XFF,0XFF,
0XC0,0X00,0X00,0X00,0X00,0X08,0XCF,0XFF,0XFF,0XFF,0X80,0X00,0X00,0X00,0X08,0XC8,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X88,0X00,0X00,0X08,0XCF,0XFF,
0XFF,0XF8,0X00,0X88,0X88,0X88,0X88,0X88,0X80,0X8F,0XC0,0X8F,0XFF,0XFF,0XFF,0XFF,
0XFF,0XC8,0X88,0X88,0X8C,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X00,0X00,0X00,0X88,0X80,
0X8C,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X00,0X00,0X00,0X00,0X08,0XCF,
0XFF,0XC8,0X00,0X08,0X88,0X88,0X88,0X8C,0X80,0X08,0X88,0XCF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X00,0X0C,0X80,0X00,
0X00,0X88,0X00,0X00,0X00,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X00,0X00,0X00,0X00,0X00,0X8C,
0XFC,0X00,0X00,0X00,0X88,0X88,0X88,0X88,0X80,0X00,0X8C,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFC,0X88,0X8C,0XCF,0XFF,0XFF,0XFF,0XF8,0X00,0X08,0X00,0X00,
0X00,0X08,0X80,0X00,0X00,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X80,0X00,0XCC,0X80,0X00,0X08,0X88,0X80,0X00,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0X88,0X00,0X00,0X00,0X00,0X8C,0XFF,0XFF,0XFF,0X80,0X88,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X08,0XFF,0XF8,0X00,0X00,0X00,0X00,0X88,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XC8,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0XCF,0XFF,0X80,0X80,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X8F,0XFF,0XFF,0XFC,0XCC,0XCC,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFC,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X8C,0XFF,0XC0,0X80,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XC8,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X8F,0XF0,0X88,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XCC,0X88,0X88,0X8C,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0XC0,0X08,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X80,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,
0XFC,0X00,0X00,0X8C,0XCC,0XC8,0X00,0X00,0X00,0X00,0X00,0X00,0XC8,0X08,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X0C,0XFF,0XFF,0XFF,0XFF,0XFC,0X80,0X00,0X00,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,
0XF8,0X00,0X08,0XFF,0XFF,0XFF,0XC8,0X00,0X00,0X00,0X00,0X00,0X08,0X00,0X80,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X8F,0XFF,0XFF,0XFF,0XFF,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,
0XC0,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XC8,0X00,0X00,0X00,0X00,0X00,0X80,0X80,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0XCF,0XFF,0XFF,0XFF,0XFC,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X8F,0XFF,0XFF,
0XC0,0X00,0XCF,0XFF,0XFF,0XFF,0XFF,0XFC,0X00,0X00,0X00,0X00,0X00,0X80,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,
0XFF,0XFF,0XFF,0XFF,0X80,0X00,0X00,0X00,0X00,0X08,0XCC,0X88,0X00,0X0C,0XFF,0XFF,
0X80,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X00,0X00,0X00,0X00,0X08,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X0C,
0XFF,0XFF,0XFF,0XFC,0X00,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFC,0X80,0X0C,0XFF,0XFF,
0X80,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF0,0X00,0X00,0X00,0X00,0X08,0X80,0X00,
0X00,0X00,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X0F,
0XFF,0XFF,0XFF,0XF8,0X00,0X00,0X00,0X08,0XCF,0XFF,0XFF,0XFF,0XF8,0X08,0XFF,0XFF,
0X80,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X00,0X00,0X00,0X00,0X08,0XF0,0X00,
0X00,0X00,0X00,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF0,0X00,0X00,0X00,0X00,0X00,0X00,0X8F,
0XFF,0XFF,0XFF,0X80,0X00,0X00,0X00,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0XFF,0XFF,
0X80,0X8F,0XFF,0XF8,0X80,0X8F,0XFF,0XFF,0XFC,0X00,0X00,0X00,0X00,0X00,0XF8,0X00,
0X00,0X00,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X00,0X00,0X00,0X00,0X00,0X00,0X8F,
0XFF,0XFF,0XFC,0X80,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0XFF,0XFF,
0X80,0X8F,0XFF,0X88,0XCC,0X08,0XCF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0XCC,0X00,
0X00,0X00,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X00,0X00,0X00,0X00,0X00,0X8F,
0XFF,0XFF,0XF8,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0XFF,0XFF,
0XF0,0X8F,0XF8,0X8C,0XFF,0XC0,0X8F,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0X8C,0X00,
0X00,0X00,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X00,0X00,0X00,0X00,0X00,0XCF,
0XFF,0XFF,0XF8,0X00,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFC,0XCF,0XFF,0XCC,0XFF,0XFF,
0XF8,0X8F,0XF8,0XCF,0XFF,0XFC,0X8F,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0X8F,0X00,
0X00,0X00,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X00,0X00,0X00,0X00,0XCF,
0XFF,0XFF,0XC0,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFC,0X80,0X00,0XCF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XF0,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0XCF,0X00,
0X00,0X00,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X88,0X88,0X80,0XFF,
0XFF,0XFF,0X80,0X00,0X00,0X00,0XCF,0XFF,0XFF,0XC8,0X8C,0XF0,0X0C,0XFF,0XFF,0XFF,
0XFF,0XFF,0XF8,0XCF,0XFF,0XFF,0XFF,0XFF,0XFC,0X00,0X00,0X00,0X00,0X00,0XCF,0X00,
0X00,0X00,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0XFF,
0XFF,0XFF,0X80,0X00,0X00,0X00,0XFF,0XFF,0XFC,0X88,0XFF,0XFF,0X08,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X00,0X00,0X00,0X00,0X00,0XFF,0X00,
0X00,0X00,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0XFF,
0XFF,0XFF,0X00,0X00,0X00,0X00,0XFF,0XFF,0XF8,0X8F,0XFF,0XFF,0XC8,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X00,0X00,0X00,0X00,0X08,0XFF,0X00,
0X00,0X00,0X00,0X00,0X00,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0XFF,
0XFF,0XFF,0X00,0X00,0X00,0X00,0XFF,0XFF,0XF8,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X00,0X00,0X00,0X00,0X00,0X8C,0XFF,0X80,
0X00,0X00,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0XFF,
0XFF,0XFC,0X00,0X00,0X00,0X00,0XFF,0XFF,0XF8,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X88,0X80,0X00,0X00,0X00,0X00,0X08,0XCF,0XFF,0X80,
0X00,0X00,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X88,0XFF,
0XFF,0XFC,0X00,0X00,0X00,0X00,0XCF,0XFF,0XFC,0XFF,0XFF,0XFF,0XFC,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X00,0X00,0X00,0X00,0X00,0X00,0X8C,0XFF,0XFF,0X80,
0X00,0X00,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X88,0XFF,
0XFF,0XFC,0X00,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0X88,0XCF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC8,0X00,0X00,0X00,0X00,0X88,0XFF,0XFF,0XFF,0X80,
0X00,0X00,0X00,0X00,0X00,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0XFF,
0XFF,0XFC,0X00,0X00,0X00,0X00,0X0C,0XFF,0XFF,0XFF,0XFF,0XFC,0X8C,0XFF,0XFF,0XFF,
0XFF,0XCC,0XCF,0XFF,0XFF,0XFF,0XFF,0XFC,0X88,0X88,0X8C,0XFF,0XFF,0XFF,0XFF,0X80,
0X00,0X00,0X00,0X00,0X00,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0XFF,
0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0XCF,0XFF,0XFF,0XFF,0XC0,0X8F,0XFF,0XFF,0XFC,
0X88,0X80,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X00,0X00,0X00,0X00,0X00,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0XFF,
0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,0X8C,0XFF,0XFF,0XC8,0X00,0XCF,0XFF,0XF8,0X80,
0X88,0X80,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X00,0X00,0X00,0X00,0X00,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0XFF,
0XFF,0XFF,0X80,0X00,0X00,0X00,0X00,0X00,0X88,0X88,0X00,0X0C,0XFF,0XFF,0XC8,0X00,
0X08,0XCC,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X00,0X00,0X00,0X00,0X00,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0XFF,
0XFF,0XFF,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XCF,0XFF,0XFF,0XFC,0XCC,
0XC0,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,
0X00,0X00,0X00,0X00,0X00,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0XFF,
0XFF,0XFF,0XF8,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,
0XF8,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,
0X00,0X00,0X00,0X00,0X00,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0XFF,
0XFF,0XFF,0XFF,0X80,0X00,0X00,0X00,0X00,0X00,0X08,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFC,0X8F,0XFF,0XFF,0XFF,0XC8,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,
0X00,0X00,0X00,0X00,0X00,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0XCF,
0XFF,0XFF,0XFF,0XC0,0X00,0X00,0X00,0X00,0X08,0X8C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0X0C,0XFF,0XFF,0XFF,0X88,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X00,
0X00,0X00,0X00,0X00,0X00,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0XCF,
0XFF,0XFF,0XFF,0XFF,0XC8,0X00,0X00,0X08,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0X00,0X8F,0XFF,0XFC,0X8C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X00,
0X00,0X00,0X00,0X00,0X00,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0XCF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XC8,0X00,0X00,0X88,0X88,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X00,
0X00,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0X8F,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XCC,0XCF,0XFC,
0X88,0XCF,0XFC,0X88,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X00,
0X00,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0X8F,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X88,0X88,0X88,
0XCC,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X00,
0X00,0X00,0X00,0X00,0X08,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF0,0X8F,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XCC,0XCF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF0,0X00,
0X00,0X00,0X00,0X00,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF0,0X8F,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF0,0X00,
0X00,0X00,0X00,0X00,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0X8F,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0X00,
0X00,0X00,0X00,0X00,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0X8F,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0X00,
0X00,0X00,0X00,0X00,0X0C,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
};

static const unsigned char gImage_P2[] = { /* 0X00,0X01,0X80,0X00,0X80,0X00, */
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X00,0X40,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X00,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X01,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X03,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X07,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X0F,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X1F,0XE0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X1F,0XE7,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X0F,0XE7,0XFC,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X0F,0XE7,0XFF,0XF0,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X0F,0XE7,0XFF,0XFF,0X80,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X0F,0XE7,0XDF,0XFF,0XF8,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X07,0XE7,0XC3,0XFF,0XFF,0X80,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X07,0XE7,0XC0,0X7F,0XFF,0XF8,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X07,0XE3,0XC0,0X0F,0XFF,0XFF,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X07,0XE3,0XC0,0X01,0XFF,0XFF,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X03,0XE3,0XC0,0X00,0X1F,0XFF,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X03,0XE3,0XC0,0X00,0X03,0XFF,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X03,0XF3,0XC0,0X00,0X00,0X3F,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X03,0XF3,0XE0,0X00,0X00,0X1F,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X01,0XF3,0XE0,0X00,0X00,0X1F,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X01,0XF3,0XE0,0X00,0X00,0X1F,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X01,0XF3,0XE0,0X00,0X00,0X1E,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X01,0XF3,0XE0,0X00,0X00,0X1E,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X00,0XF3,0XE0,0X00,0X00,0X1E,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X18,0X00,0X00,0XF3,0XE0,0X00,0X00,0X3E,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X1F,0X80,0X00,0XF3,0XE0,0X00,0X00,0X3E,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X1F,0XF8,0X00,0XF3,0XE0,0X00,0X00,0X3E,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X0F,0XFF,0X80,0X71,0XE0,0X00,0X00,0X3E,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X0F,0XFF,0XF8,0X79,0XE0,0X00,0X00,0X3C,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X0F,0XFF,0XFE,0X79,0XE0,0X00,0X00,0X3C,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X07,0XFF,0XFE,0X79,0XE0,0X00,0X00,0X3C,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X07,0XDF,0XFE,0X39,0XE0,0X00,0X00,0X3C,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X07,0XE7,0XFE,0X39,0XE0,0X00,0X00,0X3C,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X03,0XE0,0XFC,0X39,0XE0,0X00,0X00,0X3C,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X03,0XE0,0X3C,0X39,0XE0,0X00,0X00,0X3C,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X03,0XE0,0X0C,0X19,0XE0,0X00,0X00,0X38,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X03,0XF0,0X00,0X19,0XF0,0X00,0X00,0X38,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X01,0XF0,0X00,0X19,0XF0,0X00,0X00,0X38,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X01,0XF0,0X00,0X19,0XF0,0X00,0X00,0X78,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0XF8,0X00,0X09,0XF0,0X00,0X00,0X78,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0XF8,0X00,0X0D,0XF0,0X00,0X00,0X78,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0XF8,0X00,0X0C,0XF0,0X00,0X00,0X78,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X78,0X00,0X0C,0XF0,0X00,0X00,0X78,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X7C,0X00,0X04,0XF0,0X00,0X00,0X70,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X7C,0X00,0X04,0XFF,0XFF,0XFF,0XF0,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X3C,0X00,0X04,0XFF,0XFF,0XFF,0XF0,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X3E,0X00,0X00,0XFF,0XFF,0XFF,0XF0,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X1E,0X00,0X00,0XFF,0XFF,0XFF,0XF0,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X1E,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X1E,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X0F,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X0F,0XE0,0X0F,0X00,0X0C,0X3F,0X0E,0X00,0X70,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X0F,0XE0,0X00,0X00,0X0C,0X3F,0X8E,0X00,0X70,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X0C,0X00,0X00,0X00,0X0C,0X39,0XCE,0X00,0X70,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X0C,0X00,0X00,0X00,0X0C,0X39,0XC0,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X0C,0X00,0XF7,0X1E,0X3F,0X39,0XCE,0X78,0X77,0XF8,0X1F,0X70,0X00,0X01,
0X80,0X00,0X0C,0X03,0XFF,0X3F,0X3F,0X3F,0X8E,0XFC,0X77,0XFC,0X3F,0XF0,0X00,0X01,
0X80,0X00,0X0F,0XE7,0X8F,0X32,0X0C,0X3F,0X0E,0XC8,0X77,0X9C,0X78,0XF0,0X00,0X01,
0X80,0X00,0X0F,0XE7,0X07,0X38,0X0C,0X3F,0X0E,0XE0,0X77,0X1C,0X70,0X70,0X00,0X01,
0X80,0X00,0X0C,0X07,0X07,0X3E,0X0C,0X3F,0X0E,0XF8,0X77,0X1C,0X70,0X70,0X00,0X01,
0X80,0X00,0X0C,0X07,0X07,0X1F,0X0C,0X3B,0X8E,0X7C,0X77,0X1C,0X70,0X70,0X00,0X01,
0X80,0X00,0X0C,0X07,0X07,0X07,0X0C,0X3B,0X8E,0X1C,0X77,0X1C,0X70,0X70,0X00,0X01,
0X80,0X00,0X0C,0X07,0X8F,0X33,0X0C,0X39,0X8E,0XCC,0X77,0X1C,0X78,0XF0,0X00,0X01,
0X80,0X00,0X0F,0XE3,0XFF,0X7F,0X0C,0X39,0XCF,0XFC,0X77,0X1C,0X3F,0XF0,0X00,0X01,
0X80,0X00,0X0F,0XE0,0XF7,0X1E,0X0C,0X39,0XCE,0X78,0X77,0X1C,0X0F,0X70,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X70,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X70,0XE0,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X3F,0XE0,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X1F,0X80,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X3F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X01,
0X80,0X3F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X01,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X06,0X00,0X00,0X03,0X60,0X00,0X30,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X06,0X00,0X00,0X03,0X00,0X00,0X30,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X07,0XCC,0XF1,0X9F,0X67,0X9F,0X33,0XB1,0X87,0X1E,0X7F,0XC0,0X00,0X01,
0X80,0X00,0X06,0X6C,0XDB,0X33,0X6C,0XD9,0XB4,0XDB,0X0D,0XB3,0X66,0X60,0X00,0X01,
0X80,0X00,0X06,0X6C,0XDB,0X33,0X6F,0X19,0XB3,0XDB,0X0C,0X33,0X66,0X60,0X00,0X01,
0X80,0X00,0X06,0X6C,0XDB,0X33,0X63,0XD9,0XB6,0XDB,0X0C,0X33,0X66,0X60,0X00,0X01,
0X80,0X00,0X06,0X6C,0XCE,0X33,0X6C,0XD9,0XB6,0XCE,0X6D,0XB3,0X66,0X60,0X00,0X01,
0X80,0X00,0X07,0XC7,0XCE,0X1F,0X67,0X9F,0X33,0XCE,0X67,0X1E,0X66,0X60,0X00,0X01,
0X80,0X00,0X00,0X00,0X0C,0X00,0X00,0X18,0X00,0X0C,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X38,0X00,0X00,0X18,0X00,0X38,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X83,0XE0,0X70,0X07,0XFF,0X3F,0XE0,0X1F,0XF0,0X70,0X00,0X00,0X07,0X00,0X00,0X01,
0X8F,0XF8,0X70,0X07,0XFF,0X3F,0XF0,0X1F,0XF8,0X70,0X00,0X00,0X07,0X00,0X00,0X01,
0X9F,0XFC,0X70,0X07,0XFF,0X3F,0XF8,0X1F,0XFC,0X00,0X00,0X00,0X07,0X00,0X00,0X01,
0X9E,0X3C,0X70,0X07,0X00,0X38,0X38,0X1C,0X1C,0X70,0XF8,0X77,0X87,0X0F,0X8E,0X0F,
0XBC,0X1E,0X70,0X07,0X00,0X38,0X1C,0X1C,0X0E,0X71,0XFC,0X7F,0XC7,0X1F,0XCE,0X0F,
0XB8,0X0E,0X70,0X07,0XFE,0X38,0X1C,0X1C,0X0E,0X73,0X8E,0X79,0XC7,0X30,0XE7,0X1D,
0XB8,0X0E,0X70,0X07,0XFE,0X38,0X1C,0X1C,0X0E,0X73,0X80,0X70,0XE7,0X01,0XE7,0X1D,
0XB8,0X0E,0X70,0X07,0XFE,0X38,0X1C,0X1C,0X0E,0X73,0XF0,0X70,0XE7,0X0F,0XE7,0X1D,
0XB8,0X0E,0X70,0X07,0X00,0X38,0X1C,0X1C,0X0E,0X71,0XFC,0X70,0XE7,0X1E,0XE3,0XB9,
0XBC,0X1E,0X70,0X07,0X00,0X38,0X1C,0X1C,0X0E,0X70,0X7E,0X70,0XE7,0X38,0XE3,0XB9,
0X9E,0X3C,0X70,0X07,0X00,0X38,0X38,0X1C,0X1C,0X70,0X0E,0X70,0XE7,0X38,0XE1,0XB1,
0X9F,0XFC,0X7F,0XE7,0XFF,0X3F,0XF8,0X1F,0XFC,0X73,0X8E,0X79,0XC7,0X39,0XE1,0XF1,
0X8F,0XF8,0X7F,0XE7,0XFF,0X3F,0XF0,0X1F,0XF8,0X71,0XFC,0X7F,0XC7,0X1F,0XE1,0XF1,
0X83,0XE0,0X7F,0XE7,0XFF,0X3F,0XE0,0X1F,0XF0,0X70,0XF8,0X77,0X87,0X0E,0X70,0XE1,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X70,0X00,0X00,0X00,0XE1,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X70,0X00,0X00,0X01,0XC1,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X70,0X00,0X00,0X07,0XC1,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X70,0X00,0X00,0X07,0X81,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X03,0X00,0X00,0X03,0X60,0X00,0X30,0X00,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X03,0X00,0X00,0X03,0X00,0X00,0X30,0X00,0X00,0X00,0X00,0X01,
0X86,0X4D,0X93,0X64,0XC3,0XE6,0X78,0XDF,0X67,0X9F,0X33,0XB1,0X87,0X1E,0X7F,0XC1,
0X86,0XED,0XBB,0X6E,0XC3,0X36,0X6D,0XB3,0X6C,0XD9,0XB4,0XDB,0X0D,0XB3,0X66,0X61,
0X86,0XED,0XBB,0X6E,0XC3,0X36,0X6D,0XB3,0X6F,0X19,0XB3,0XDB,0X0C,0X33,0X66,0X61,
0X83,0XB8,0XEE,0X3B,0X83,0X36,0X6D,0XB3,0X63,0XD9,0XB6,0XDB,0X0C,0X33,0X66,0X61,
0X83,0XB8,0XEE,0X3B,0X9B,0X36,0X67,0X33,0X6C,0XD9,0XB6,0XCE,0X6D,0XB3,0X66,0X61,
0X83,0X18,0XC6,0X31,0X9B,0XE3,0XE7,0X1F,0X67,0X9F,0X33,0XCE,0X67,0X1E,0X66,0X61,
0X80,0X00,0X00,0X00,0X00,0X00,0X06,0X00,0X00,0X18,0X00,0X0C,0X00,0X00,0X00,0X01,
0X80,0X00,0X00,0X00,0X00,0X00,0X1C,0X00,0X00,0X18,0X00,0X38,0X00,0X00,0X00,0X01,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,

};

static const uint8_t Signal816[16] = //mobie singal
{
    0xFE,0x02,0x92,0x0A,0x54,0x2A,0x38,0xAA,0x12,0xAA,0x12,0xAA,0x12,0xAA,0x12,0xAA
};

static const uint8_t Msg816[16] =  //message
{
    0x1F,0xF8,0x10,0x08,0x18,0x18,0x14,0x28,0x13,0xC8,0x10,0x08,0x10,0x08,0x1F,0xF8
};

static const uint8_t Bat816[16] = //batery
{
    0x0F,0xFE,0x30,0x02,0x26,0xDA,0x26,0xDA,0x26,0xDA,0x26,0xDA,0x30,0x02,0x0F,0xFE
};

static const uint8_t Bluetooth88[8] = // bluetooth
{
    0x18,0x54,0x32,0x1C,0x1C,0x32,0x54,0x18
};

static const uint8_t GPRS88[8] = //GPRS
{
    0xC3,0x99,0x24,0x20,0x2C,0x24,0x99,0xC3
};

static const uint8_t Alarm88[8] = //alram
{
    0xC3,0xBD,0x42,0x52,0x4E,0x42,0x3C,0xC3
};

#endif  

	 
	 



